#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['fastasyncapi']

package_data = \
{'': ['*']}

setup(name='fastasyncapi',
      version='0.1',
      description='Python FastAsyncApi project!',
      author=None,
      author_email='Mohsen Mahmoodi <m.mahmoodi.biz@gmail.com>',
      url=None,
      packages=packages,
      package_data=package_data,
     )
